![](docs/figs/spode_logo_v0.png)

Spode is an opensource differentiable simulator specialized for programmable photonics. **It is currently under active development.**

## Installationß

```
pip install spode
```

## Quick Tutorial

[Lesson 1: a tunable basic unit](https://github.com/zhengqigao/spode/blob/main/tutorials/lesson1_verify_tbu/)

[Lesson 2: a 2 by 2 square mesh](https://github.com/zhengqigao/spode/blob/main/tutorials/lesson2_verify_2by2_mesh/)


## Contact and Bug Report

